@@ -322,7 +322,7 @@ where
 }
 
 #[tracing::instrument(name = "Static files")]
-fn static_files(filename: web::Path<String>, state: web::Data<State>) -> HttpResponse {
+async fn static_files(filename: web::Path<String>, state: web::Data<State>) -> HttpResponse {
     let filename = filename.into_inner();
 
     if let Some(data) = self::templates::statics::StaticFile::get(&filename) {
