@@ -1,5 +1,6 @@
 use actix_web::{App, HttpServer};
 use awc::Client;
+#[cfg(feature = "console")]
 use console_subscriber::ConsoleLayer;
 use opentelemetry::{
     sdk::{propagation::TraceContextPropagator, Resource},
@@ -62,6 +63,7 @@ fn init_logger(opentelemetry_url: Option<&Url>) -> Result<(), Box<dyn std::error
         .with_span_events(FmtSpan::NEW | FmtSpan::CLOSE)
         .with_filter(targets.clone());
 
+    #[cfg(feature = "console")]
     let console_layer = ConsoleLayer::builder()
         .with_default_env()
         .server_addr(([0, 0, 0, 0], 6669))
@@ -69,10 +71,12 @@ fn init_logger(opentelemetry_url: Option<&Url>) -> Result<(), Box<dyn std::error
         .spawn();
 
     let subscriber = Registry::default()
-        .with(console_layer)
         .with(format_layer)
         .with(ErrorLayer::default());
 
+    #[cfg(feature = "console")]
+    let subscriber = subscriber.with(console_layer);
+
     if let Some(url) = opentelemetry_url {
         let tracer =
             opentelemetry_otlp::new_pipeline()
